"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFtpConfig = exports.config = void 0;
const http_1 = __importDefault(require("http"));
const https_1 = __importDefault(require("https"));
const fs_1 = __importDefault(require("fs"));
exports.config = (ctx) => {
    let userConfig = ctx.getConfig('picBed.ftp-uploader');
    if (!userConfig) {
        userConfig = {
            site: '',
            configFile: ''
        };
    }
    return [
        {
            name: 'site',
            type: 'input',
            default: userConfig.site,
            required: true,
            message: 'imba97',
            alias: '网站标识'
        },
        {
            name: 'configFile',
            type: 'input',
            default: userConfig.configFile,
            required: true,
            message: 'D:/ftpUploaderConfig.json',
            alias: '配置文件'
        }
    ];
};
exports.getFtpConfig = (userConfig) => {
    return new Promise((resolve, reject) => {
        // 兼容 https
        let request = null;
        if (/^https/.test(userConfig.configFile)) {
            request = https_1.default;
            process.env.NODE_TLS_REJECT_UNAUTHORIZED = '0';
        }
        else if (/^http/.test(userConfig.configFile)) {
            request = http_1.default;
        }
        // 如果是网址 则用 http 否则是本地 用 fs
        if (request !== null) {
            // 网络
            request
                .get(userConfig.configFile, (res) => {
                if (res.statusCode !== 200) {
                    reject(res.statusCode);
                    res.resume();
                    return;
                }
                res.setEncoding('utf8');
                let body = '';
                res.on('data', (chunk) => {
                    body += chunk;
                });
                res.on('end', () => {
                    resolve(JSON.parse(body));
                });
            })
                .on('error', (e) => {
                reject(e.message);
            });
        }
        else {
            // 本地
            resolve(JSON.parse(fs_1.default.readFileSync(userConfig.configFile).toString()));
        }
    });
};
